@@ -2,8 +2,8 @@ use crate::checker;
 use std::path::PathBuf;
 use std::process::Command;
 
-pub fn run(dir: &PathBuf, command: &Vec<String>) {
-    checker::check(dir, false, true);
+pub fn run_command(dir: &PathBuf, command: &Vec<String>) {
+    checker::check_command(dir, false, true);
     // Run the command with the given args
     let binary = command.get(0).unwrap();
     let other_args = command
@@ -17,7 +17,13 @@ pub fn run(dir: &PathBuf, command: &Vec<String>) {
             std::process::exit(code.code().unwrap());
         }
         Err(e) => {
-            panic!("{}", e);
+            // Check if e is of type file_not_found
+            if e.kind() == std::io::ErrorKind::NotFound {
+                eprintln!("{} Make sure the binary is in your PATH (not an alias)", e);
+                std::process::exit(1);
+            } else {
+                panic!("{}", e);
+            }
         }
     }
 }
